/*
 *      macnotify.cpp
 *
 *      Copyright 2021 David Vachulka <arch_dvx@users.sourceforge.net>
 *
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 3 of the License, or
 *      (at your option) any later version.
 *
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *
 *      You should have received a copy of the GNU General Public License
 *      along with this program; if not, write to the Free Software
 *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 *      MA 02110-1301, USA.
 */

#include "macnotify.h"
#import <objc/runtime.h>
#include <Cocoa/Cocoa.h>

@implementation NSBundle(returnCorrectIdentifier)
- (NSString *)__bundleIdentifier
{
    if(self == [NSBundle mainBundle])
    {
        return @"org.dxirc.dxirc";
    }
    else
    {
        return [self __bundleIdentifier];
    }
}
@end

void MacNotify::showNotify(const QString &text)
{
    NSUserNotification* userNotification = [[NSUserNotification alloc] init];
    userNotification.title = @"dxirc";
    userNotification.informativeText = text.toNSString();
    [[NSUserNotificationCenter defaultUserNotificationCenter] deliverNotification: userNotification];
    [userNotification release];
}

MacNotify *MacNotify::instance()
{
    static MacNotify *s_instance = nullptr;
    if(!s_instance)
    {
        s_instance = new MacNotify();
        Class aPossibleClass = objc_getClass("NSBundle");
        if(aPossibleClass)
        {
            // change NSBundle -bundleIdentifier method to return a correct bundle identifier
            // a bundle identifier is required to use OSXs User Notification Center
            method_exchangeImplementations(class_getInstanceMethod(aPossibleClass, @selector(bundleIdentifier)),
                                           class_getInstanceMethod(aPossibleClass, @selector(__bundleIdentifier)));
            }
    }
    return s_instance;
}


